Conversion from keepass to vault
--------------------------------

Usage: keepass_import.py --help

Running the tests
-----------------

Requires the TCP port 8200 is available and will destroy the container `test-import-keepass` if it exists.

* install docker
* tox
